#!/usr/bin/env python3
import logging
import sentry_sdk
from sentry_sdk.integrations.logging import LoggingIntegration
from utils import config, LoopingTimer
from signal_processor import SoundSignalProcessor

"""
Main Entrypoint
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2020, Birbnetes Team"
__module_name__ = "app"
__version__text__ = "1"

sentry_logging = LoggingIntegration(
    level=logging.INFO,
    event_level=logging.ERROR
)

if config.SENTRY_DSN:
    sentry_sdk.init(
        dsn=config.SENTRY_DSN,
        integrations=[sentry_logging],
        traces_sample_rate=1.0,
        send_default_pii=True,
        release=config.RELEASE_ID,
        environment=config.RELEASEMODE,
        _experiments={"auto_enabling_integrations": True}
    )


def timer_tick(*args) -> None:
    """
    Tick of a timer
    :param listofabcsignaprocessors:
    :return:
    """
    for abcsignaprocessor in args:
        abcsignaprocessor.processcurrentsignal()


def main() -> None:
    """
    Main function
    :return:
    """
    listofabcsignaprocessors = (SoundSignalProcessor())
    loopingtimer = LoopingTimer(function=timer_tick, args=[listofabcsignaprocessors], interval=config.TICK_INTERVAL)
    loopingtimer.start()


if __name__ == "__main__":
    main()
